@@ -92,8 +92,7 @@ async function handler(event) {
     const putObject = await s3.putObject({
       Bucket: getEnv("BUCKET_NAME"),
       Key: key,
-      WebsiteRedirectLocation: body.url,
-      ACL: "public-read"
+      WebsiteRedirectLocation: body.url
     }).promise();
     console.log("Put object: %j", putObject);
     return __spreadProps(__spreadValues({}, response), {
